/*   msXpertSuite - mass spectrometry software suite
 *   -----------------------------------------------
 *   Copyright(C) 2016 Filippo Rusconi
 *
 *   http://www.{site}.org
 *
 *   This file is part of the msXpertSuite project.
 *
 *   The msXpertSuite project is the successor of the massXpert project. This
 *   project now includes various independent modules:
 *   - massXpert, the original mass spectrometry environment software (greatly
 *     refactored code);
 *   - mobXpert, a module to process and mine mobility mass spectrometry data;
 *   - viewXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */


/////////////////////// Qt includes
#include <QDebug>

/////////////////////// Local includes
#include "MassSpecDataSet.hpp"


namespace msXpertSuite
{

 MassSpecDataSet::MassSpecDataSet(QObject *parent, const QString &name,
 const QString &fileName)
 : QObject{parent}, m_name{name}, m_fileName{fileName}
 {
 }


 MassSpecDataSet::~MassSpecDataSet()
 {
 int size = m_massSpectra.size();

 qDebug() << __FILE__ << __LINE__
 << "Entering MassSpecDataSet::~MassSpecDataSet to free" << size
 << "mass spectra";

 // The MassSpectrumList member of this class does not automatically delete
 // the
 // MassSpectrum instances allocated on the heap: that class is used to
 // get pointers to MassSpectrum instances that do not belong to the
 // MassSpectrumList object.

 // The user of the MassSpectrumList object is responsible for calling
 // freeSpectra() at the right moment (typically from here).

 m_massSpectra.freeSpectra();

 qDebug() << __FILE__ << __LINE__
 << "In MassSpecDataSet::~MassSpecDataSet(): freed " << size
 << "mass spectra, freed memory. ";

 m_rtHash.clear();
 m_dtHash.clear();
 }


 void
 MassSpecDataSet::setParent(QObject *parent)
 {
 QObject::setParent(parent);
 }


 void
 MassSpecDataSet::appendMassSpectrum(MassSpectrum *massSpectrum)
 {
 if(massSpectrum == nullptr)
 qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);

 m_massSpectra.append(massSpectrum);
 }


 void
 MassSpecDataSet::insertRtHash(double key, MassSpectrum *value)
 {
 if(value == nullptr)
 qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);

 m_rtHash.insert(key, value);
 }


 void
 MassSpecDataSet::insertDtHash(double key, MassSpectrum *value)
 {
 if(value == nullptr)
 qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);

 m_dtHash.insert(key, value);
 }


} // namespace msXpertSuite
