/*   msXpertSuite - mass spectrometry software suite
 *   -----------------------------------------------
 *   Copyright(C) 2016 Filippo Rusconi
 *
 *   http://www.{site}.org
 *
 *   This file is part of the msXpertSuite project.
 *
 *   The msXpertSuite project is the successor of the massXpert project. This
 *   project now includes various independent modules:
 *   - massXpert, the original mass spectrometry environment software (greatly
 *     refactored code);
 *   - mobXpert, a module to process and mine mobility mass spectrometry data;
 *   - viewXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */


#ifndef MASS_SPEC_DATA_SET_HPP
#define MASS_SPEC_DATA_SET_HPP

/////////////////////// Qt includes


/////////////////////// Local includes
#include "globals.hpp"
#include "MassSpectrumList.hpp"
#include "MsMultiHash.hpp"


namespace msXpertSuite
{

 class MassSpecDataSet : public QObject
 {
 Q_OBJECT;

 public:
 QString m_name;
 QString m_fileName;

 MassSpecDataFileFormat m_fileFormat;

 int fileVersion;

 // The mineXpert software may be operated in two modes:
 // 1. streamed, that means that data are systematically read from disk and
 // never totally stored in RAM;
 // 2. not stread, that is full, where the data are totally read from disk
 // into RAM and used from RAM.
 //
 // Note that when the m_isStreamed value is true, the user MUST allocate on
 // the heap a new MassSpectrum and append it to the m_massSpectra member
 // because that spectrum is going to be the combination of the whole set of
 // loaded mass spectra from file. Fron there, the ticChromMap will be filled
 // up once all the data will have been loaded.
 bool m_isStreamed = false;

 // The spectra in the list are owed by us. We have to remove them upon
 // destruction.
 MassSpectrumList m_massSpectra;
 MsMultiHash m_rtHash;
 MsMultiHash m_dtHash;

 // When the data are loaded in a streamed way, the TIC chromatogram is
 // computed "live" and must be stored in this map:
 QMap<double, double> m_ticChromMap;

 int m_mzCellCount = -1;
 double m_mzRangeStart = 1000000;
 double m_mzRangeEnd = 0;

 // Construction / Destruction

 MassSpecDataSet(QObject *parent = nullptr, const QString &name = QString(),
 const QString &fileName = QString());
 ~MassSpecDataSet();

 void setParent(QObject *parent);

 void appendMassSpectrum(MassSpectrum *massSpectrum);

 void insertRtHash(double key, MassSpectrum *value);

 void insertDtHash(double key, MassSpectrum *value);
 };


} // namespace msXpertSuite

#endif /* MASS_SPEC_DATA_SET_HPP */
