/*   msXpertSuite - mass spectrometry software suite
 *   -----------------------------------------------
 *   Copyright(C) 2016 Filippo Rusconi
 *
 *   http://www.{site}.org
 *
 *   This file is part of the msXpertSuite project.
 *
 *   The msXpertSuite project is the successor of the massXpert project. This
 *   project now includes various independent modules:
 *   - massXpert, the original mass spectrometry environment software (greatly
 *     refactored code);
 *   - mineXpert, a powerful TIC chromatogram/mass/drift spectrum viewer/miner;
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */


#ifndef MASS_SPEC_SQLITE3_HANDLER_HPP
#define MASS_SPEC_SQLITE3_HANDLER_HPP

/////////////////////// Qt includes
#include <QtSql>
#include <QSqlDatabase>
#include <QStringList>

/////////////////////// Local includes
#include "globals.hpp"
#include "SqlTableFieldSpecifs.hpp"
#include "SqlTableSpecifs.hpp"
#include "MassSpecFileMetaData.hpp"
#include "MassSpecDataSet.hpp"
#include "MassSpectrum.hpp"
#include "MassSpectrumList.hpp"
#include "History.hpp"


namespace msXpertSuite
{


  class MassSpecSqlite3Handler : public QObject
  {
    Q_OBJECT

    public:

    QString      m_dbFileName;
    QSqlDatabase m_db;

    // How many spectra do we parse before providing a feedback message on the
    // progression of the parsing of the file?
    int m_parseProgressionNumber = 100;

    SqlTableSpecifs m_metaDataTableSpecifs;
    SqlTableSpecifs m_spectralDataTableSpecifs;
    SqlTableSpecifs m_chromatographicDataTableSpecifs;
    SqlTableSpecifs m_driftDataTableSpecifs;
    SqlTableSpecifs m_precursorIonsTableSpecifs;

    MassSpecFileMetaData m_msFileMetaData;

    bool createMetaDataTableSpecifs();

    QString
    metaDataTableInsertSqlCommand(const MassSpecFileMetaData &specMetaData);

    bool createSpectralDataTableSpecifs();

    bool createChromatographicDataTableSpecifs();

    bool createDriftDataTableSpecifs();

    bool createPrecursorIonsTableSpecifs();

    QString tableCreationSqlCommand(QString tableName);

    bool createDbTables(QSqlDatabase *db = nullptr);

    MassSpecSqlite3Handler(const QString &fileName = QString());

    ~MassSpecSqlite3Handler();

    bool initializeDbForWrite();
    bool initializeDbForRead(const QString &fileName = QString());

    void closeDb();

    bool writeDbMassSpecFileMetaData(const MassSpecFileMetaData &specMetaData,
                                     QSqlDatabase *              db = nullptr);

    bool writeDbDriftData(double driftTime, int driftBin, int *recordId,
                          QSqlDatabase *db = nullptr);

    bool writeDbPrecursorIons(const QString &mzList, const QString &iList,
                              int *recordId, QSqlDatabase *db = nullptr);

    bool writeDbSpectralData(int idx, const QString &title, int peakCount,
                             int msLevel, double tic, double collisionEnergy,
                             int precursorIonId, double scanStartTime,
                             int driftDataId, double mzStart, double mzEnd,
                             const QByteArray &mzByteArray,
                             const QByteArray &iByteArray,
                             QSqlDatabase *    db = nullptr);

    bool writeDbChromatographicData(int idx, const QString &title,
                                    const QByteArray &timeByteArray,
                                    const QByteArray &iByteArray);

    MassSpecFileMetaData massSpecFileMetaData();
    void massSpecFileMetaData(QStringList keys, QList<int> intValues);

    QList<double> *driftTimeList();
    void mzRange(double &mzStart, double &mzEnd);
    QList<double> rtList();

    int spectrumListCount();

    int recordCountByScanStartTime(double start = 0, double end = -1);
    QList<double> scanStartTimeUniqueValues(double start = 0, double end = -1);

    bool isDriftExperiment();
    bool hasPrecursorIons();

    bool exportData_metaData(QSqlDatabase *db, int spectrumListCount);
    bool exportData_driftData(QSqlDatabase *db);
    bool exportData_precursorIons(QSqlDatabase *db);
    bool exportData(QString fileName, History history);

    signals:
    void dataLoadMessageSignal(QString msg, int logType);
    void dataLoadProgressSignal(int spectrumIndex);
    void setupProgressFeedbackSignal(QString msg, int startValue, int endValue,
                                     int currentValue = -1);
    void updateProgressFeedbackSignal(QString msg, int currentValue);
  };
}
// namespace msXpertSuite

#endif /* MASS_SPEC_SQLITE3_HANDLER_HPP */
