/*   msXpertSuite - mass spectrometry software suite
 *   -----------------------------------------------
 *   Copyright(C) 2016 Filippo Rusconi
 *
 *   http://www.{site}.org
 *
 *   This file is part of the msXpertSuite project.
 *
 *   The msXpertSuite project is the successor of the massXpert project. This
 *   project now includes various independent modules:
 *   - massXpert, the original mass spectrometry environment software (greatly
 *     refactored code);
 *   - mineXpert, a powerful TIC chromatogram/mass/drift spectrum viewer/miner;
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */


// Qt includes
#include <QDebug>


// Local includes
#include "SqlTableSpecifs.hpp"


namespace msXpertSuite
{

  SqlTableSpecifs::SqlTableSpecifs(QString tableName, QString comment,
                                   QString commandLine)
  {
    m_tableName   = tableName;
    m_comment     = comment;
    m_commandLine = commandLine;
  }


  SqlTableSpecifs::SqlTableSpecifs(const QString &tableName)
  {
    m_tableName = tableName;
  }


  void
  SqlTableSpecifs::clearTableFieldMetaData()
  {
    while(m_sqlTableFieldMetaDataList.size())
      delete(m_sqlTableFieldMetaDataList.takeFirst());
  }


  void
  SqlTableSpecifs::reset()
  {
    clearTableFieldMetaData();
    m_tableName   = "";
    m_comment     = "";
    m_commandLine = "";
  }


  SqlTableSpecifs::~SqlTableSpecifs()
  {
    clearTableFieldMetaData();
  }


  void
  SqlTableSpecifs::setTableName(QString tableName)
  {
    m_tableName = tableName;
  }


  QString
  SqlTableSpecifs::tableName() const
  {
    return m_tableName;
  }


  void
  SqlTableSpecifs::setComment(QString comment)
  {
    m_comment = comment;
  }


  QString
  SqlTableSpecifs::comment() const
  {
    return m_comment;
  }


  void
  SqlTableSpecifs::setCommandLine(QString commandLine)
  {
    m_commandLine = commandLine;
  }


  QString
  SqlTableSpecifs::commandLine() const
  {
    return m_commandLine;
  }


  void
  SqlTableSpecifs::appendTableFieldMetaData(SqlTableFieldSpecifs *specifs)
  {
    if(!specifs)
      {
        qDebug() << __FILE__ << __LINE__
                 << "Argument 'specifs' cannot be 0. Exiting\n";

        exit(1);
      }

    m_sqlTableFieldMetaDataList.append(specifs);
  }


  QString
  SqlTableSpecifs::tableCreationSqlString()
  {
    // Note that all the command lines in the fieldMetaData items are not
    // punctuated, which means that we have to
    // make sure we make a join with ','.

    // m_commandLine is the string that holds the section of the sql command
    // that
    // actually creates the table and the id number of their items, like
    // "CREATE TABLE table(table_id INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL"
    // and that is followed by the specification of all the fields of the table.

    QString sqlString = m_commandLine;
    for(int iter = 0; iter < m_sqlTableFieldMetaDataList.size(); ++iter)
      {
        SqlTableFieldSpecifs *curItem = m_sqlTableFieldMetaDataList.at(iter);

        QString sqlCommand = curItem->commandLine();

        sqlString += QString(", %1").arg(sqlCommand);
      }

    // We need to close the sql command line:
    sqlString += ")";

    return sqlString;
  }

} // namespace msXpertSuite
