/*   msXpertSuite - mass spectrometry software suite
 *   -----------------------------------------------
 *   Copyright(C) 2016 Filippo Rusconi
 *
 *   http://www.{site}.org
 *
 *   This file is part of the msXpertSuite project.
 *
 *   The msXpertSuite project is the successor of the massXpert project. This
 *   project now includes various independent modules:
 *   - massXpert, the original mass spectrometry environment software (greatly
 *     refactored code);
 *   - mineXpert, a powerful TIC chromatogram/mass/drift spectrum viewer/miner;
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */


#ifndef CROSS_LINKER_DEF_DLG_HPP
#define CROSS_LINKER_DEF_DLG_HPP


/////////////////////// Local includes
#include "AbstractPolChemDefDependentDlg.hpp"
#include "ui_CrossLinkerDefDlg.h"


namespace msXpertSuite
{

  class PolChemDef;
  class PolChemDefWnd;
  class CrossLinker;
  class Modif;


  class CrossLinkerDefDlg : public AbstractPolChemDefDependentDlg
  {
    Q_OBJECT

    private:
    Ui::CrossLinkerDefDlg m_ui;

    QList<CrossLinker *> *mp_list;

    void closeEvent(QCloseEvent *event);

    void writeSettings();
    void readSettings();

    public:
    CrossLinkerDefDlg(PolChemDef *polChemDef, PolChemDefWnd *polChemDefWnd,
                      const QString &settingsFilePath);

    ~CrossLinkerDefDlg();

    bool initialize();
    bool populateAvailableModifList();

    void updateCrossLinkerIdentityDetails(CrossLinker *);
    void updateModifDetails(Modif *);

    void clearAllDetails();

    public slots:

    // ACTIONS
    void addCrossLinkerPushButtonClicked();
    void removeCrossLinkerPushButtonClicked();
    void moveUpCrossLinkerPushButtonClicked();
    void moveDownCrossLinkerPushButtonClicked();

    void addModifPushButtonClicked();
    void removeModifPushButtonClicked();
    void moveUpModifPushButtonClicked();
    void moveDownModifPushButtonClicked();

    void applyCrossLinkerPushButtonClicked();
    void applyModifPushButtonClicked();

    bool validatePushButtonClicked();

    // VALIDATION
    bool validate();

    // WIDGETRY
    void crossLinkerListWidgetItemSelectionChanged();
    void modifListWidgetItemSelectionChanged();
  };

} // namespace msXpertSuite


#endif // CROSS_LINKER_DEF_DLG_HPP
