/*   msXpertSuite - mass spectrometry software suite
 *   -----------------------------------------------
 *   Copyright(C) 2016 Filippo Rusconi
 *
 *   http://www.{site}.org
 *
 *   This file is part of the msXpertSuite project.
 *
 *   The msXpertSuite project is the successor of the massXpert project. This
 *   project now includes various independent modules:
 *   - massXpert, the original mass spectrometry environment software (greatly
 *     refactored code);
 *   - mineXpert, a powerful TIC chromatogram/mass/drift spectrum viewer/miner;
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */



/////////////////////// Qt includes
#include <QMessageBox>


/////////////////////// Local includes
#include "globals.hpp"
#include "DecimalPlacesOptionsDlg.hpp"


namespace msXpertSuite
{
  
  DecimalPlacesOptionsDlg::DecimalPlacesOptionsDlg(QWidget *parent,
			const QString &configSettingsFilePath)
    : QDialog(parent)
  {
    m_ui.setupUi(this);
    
    mp_editorWnd = static_cast<SequenceEditorWnd *>(parent);
    
    QSettings settings(m_configSettingsFilePath, 
       QSettings::IniFormat);
    
    settings.beginGroup("decimal_places_options_dlg");
    
    restoreGeometry(settings.value("geometry").toByteArray());

    settings.endGroup();

    m_ui.atomDecimalPlacesSpinBox->setValue(ATOM_DEC_PLACES);
    m_ui.oligomerDecimalPlacesSpinBox->setValue(OLIGOMER_DEC_PLACES);
    m_ui.polymerDecimalPlacesSpinBox->setValue(POLYMER_DEC_PLACES); 
    m_ui.pKaPhPiDecimalPlacesSpinBox->setValue(PH_PKA_DEC_PLACES);
    
    connect(m_ui.validatePushButton,
	     SIGNAL(clicked()),
	     this,
	     SLOT(validate()));
  }


DecimalPlacesOptionsDlg::~DecimalPlacesOptionsDlg()
{
}


void 
DecimalPlacesOptionsDlg::closeEvent(QCloseEvent *event)
{
  Q_UNUSED(event);
  
    QSettings settings(m_configSettingsFilePath, 
       QSettings::IniFormat);
  
  settings.beginGroup("decimal_places_options_dlg");

  settings.setValue("geometry", saveGeometry());
  
  settings.endGroup();
}


SequenceEditorWnd *
DecimalPlacesOptionsDlg::editorWnd()
{
  return mp_editorWnd;
}


void 
DecimalPlacesOptionsDlg::validate()
{
  
  ATOM_DEC_PLACES = m_ui.atomDecimalPlacesSpinBox->value(); 
  OLIGOMER_DEC_PLACES = m_ui.oligomerDecimalPlacesSpinBox->value(); 
  POLYMER_DEC_PLACES = m_ui.polymerDecimalPlacesSpinBox->value(); 
  PH_PKA_DEC_PLACES = m_ui.pKaPhPiDecimalPlacesSpinBox->value(); 

    QSettings settings(m_configSettingsFilePath, 
       QSettings::IniFormat);
  
  settings.beginGroup("decimal_places_options");

  settings.setValue("ATOM_DEC_PLACES", ATOM_DEC_PLACES);
  settings.setValue("OLIGOMER_DEC_PLACES", OLIGOMER_DEC_PLACES);
  settings.setValue("POLYMER_DEC_PLACES", POLYMER_DEC_PLACES);
  settings.setValue("PH_PKA_DEC_PLACES", PH_PKA_DEC_PLACES);
  
  settings.endGroup();

  // At this point ask that masses be redisplayed, for the sequence
  // editor window.

	emit(updateWholeSequenceMasses());
	emit(updateSelectedSequenceMasses());
}

} // namespace msXpertSuite
