/*   msXpertSuite - mass spectrometry software suite
 *   -----------------------------------------------
 *   Copyright(C) 2016 Filippo Rusconi
 *
 *   http://www.{site}.org
 *
 *   This file is part of the msXpertSuite project.
 *
 *   The msXpertSuite project is the successor of the massXpert project. This
 *   project now includes various independent modules:
 *   - massXpert, the original mass spectrometry environment software (greatly
 *     refactored code);
 *   - mineXpert, a powerful TIC chromatogram/mass/drift spectrum viewer/miner;
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */


#include <QRegExp>
#include <QDebug>
#include <QFile>
#include <QDir>
#include <QString>

#include "Options.hpp"


Options globalOptions;


Options::Options()
{
}


Options::Options(const QString &mzmlFilename, const QString &dbFilename)
  : m_mzmlFilename(mzmlFilename), m_dbFilename(dbFilename)
{
}


Options::~Options()
{
}


QString
Options::mzmlFilename() const
{
  return m_mzmlFilename;
};


void
Options::setMzmlFilename(const QString &mzmlFilename)
{
  m_mzmlFilename = mzmlFilename;
}


QString
Options::dbFilename() const
{
  return m_dbFilename;
};


void
Options::setDbFilename(const QString &dbFilename)
{
  m_dbFilename = dbFilename;
}


void
Options::craftSetDbFilename(const QString &dirAbsPath)
{
  // First, transmute the mzml filename into a db filename,
  // whatever the dirAbsPath argument.

  QString dbFilename = globalOptions.mzmlFilename();
  dbFilename.replace(QRegExp("\\.mzml$"), ".db");

  if(dbFilename == globalOptions.mzmlFilename())
    {
      // This means that the replace did not work out.
      // We do not want to overwrite the original mzml file
      // and thus we craft a brand new file by appending .db.
      dbFilename += ".db";
    }

  QString dbFilePath;

  if(!dirAbsPath.isEmpty())
    {
      // We craft a filename using dirName as path.
      dbFilePath = dirAbsPath;
      dbFilePath.append("/");
      dbFilePath.append(QFileInfo(dbFilename).fileName());
    }
  else
    {
      dbFilePath = dbFilename;
    }

  qDebug() << __FILE__ << __LINE__
           << "Crafted a new db filename:" << dbFilePath;

  m_dbFilename = dbFilePath;
}


int
Options::parseProgNumb()
{
  return m_parseProgNumb;
}

void
Options::setParseProgNumb(uint value)
{
  m_parseProgNumb = value;
}


QString
Options::checkMzmlFileOptions()
{
  QString error;

  if(m_mzmlFilename.isEmpty())
    {
      error += "The mzML filename is either invalid or empty.\n";
    }
  else
    {
      QFile mzmlFile(m_mzmlFilename);
      if(!mzmlFile.exists())
        {
          error += "The mzML file does not exist.\n";
        }
    }

  return error;
}
